#TODO: Clean up recipe.
base_directory = node[:resin][:base_dir]
resin_file = "#{Chef::Config[:file_cache_path]}/resin-pro-4.tar.gz"
resin_directory = "#{base_directory}/resin-pro-#{node[:resin][:version]}"
resin_alias = "#{base_directory}/resin"
resin_user = node[:resin][:user]
packages = %w( geos proj libspatialite sqlite htop tree wget
              libgeotiff libpng pcre  libgeotiff libpng )

directory base_directory do
  owner resin_user
end

include_recipe 'build-essential'
include_recipe 'java'

# If Linux, set some basic system stuff up
unless platform_family?('mac_os_x')
  include_recipe 'sysctl::apply'

  user_ulimit(node[:main_user]) do
    filehandle_limit 65536
    process_limit 25000
  end

  user_ulimit(node[:main_user]) do
    filehandle_limit 65536
    process_limit 25000
  end

  packages.insert(%w[ unzip git bzip2 cloud-utils sysstat ])
end

if platform_family?('mac_os_x')
  %w[ /opt ].each do |path|
    directory(path) do
      owner resin_user
      action :create
      recursive true
    end
  end
end

if platform_family?('rhel')
  include_recipe 'yum-epel'

  yum_repository('ELGIS') do
    description 'Enterprise Linux GIS'
    enabled true
    gpgcheck true
    baseurl 'http://elgis.argeo.org/repos/6/elgis/x86_64/'
    gpgkey 'http://elgis.argeo.org/RPM-GPG-KEY-ELGIS'
  end
end

# Install all packages.
packages.each do |library|
  package library
end

remote_file resin_file do
  source "http://caucho.com/download/resin-pro-#{node[:resin][:version]}.tar.gz"
end

execute 'untar resin' do
  command "tar -xzf #{resin_file} --directory #{base_directory}"
  creates resin_directory
  user resin_user
end

execute 'link resin' do
  command "ln -sf #{resin_directory} #{resin_alias}"
  user resin_user
end

directory "#{resin_alias}/ext-lib" do
  recursive true
  owner resin_user
end

bash 'install resin' do
  code <<-EOH
    ./configure --prefix=#{resin_directory}
    make
    make install
  EOH
  cwd resin_directory
  user resin_user
  not_if do
    if platform_family?('mac_os_x')
      File::exist?("#{resin_directory}/libexec64/libresin.jnilib")
    else
      File::exist?("#{resin_directory}/libexec64/libresin.so")
    end
  end
end

data_bag_item('resin', 'licenses')['license_keys'].each do |license_key,license_value|
  file "#{resin_directory}/licenses/#{license_key}.license" do
    content license_value
    backup 0
  end
end

unless node[:resin][:sqlitejdbc].nil?
  sqlite_version = node[:resin][:sqlitejdbc][:version]
  remote_file 'install sqlitejdbc' do
    path "#{resin_alias}/ext-lib/sqlite-jdbc-#{sqlite_version}.jar"
    source "http://search.maven.org/remotecontent?filepath=org/xerial/sqlite-jdbc/#{sqlite_version}/sqlite-jdbc-#{sqlite_version}.jar"
  end
end

unless node[:resin][:postgresql].nil?
  psql_version = node[:resin][:postgresql][:version]
  remote_file 'install progresql jdbc' do
    path "#{resin_alias}/ext-lib/postgresql-#{psql_version}.jar"
    source "http://search.maven.org/remotecontent?filepath=org/postgresql/postgresql/#{psql_version}/postgresql-#{psql_version}.jar"
  end
end

if platform_family?('mac_os_x')
  #TODO: Fix this so it takes effect on boot.
  execute "launchctl setenv RESIN_HOME #{resin_alias}"
else
  magic_shell_environment 'RESIN_HOME' do
    value resin_alias
  end
end